$LOAD_PATH.unshift "#{File.dirname(__FILE__)}/../../lib"

require_relative '../common'
require 'minitest'
require 'mocha/minitest'
require 'pty'
require 'expect'
